@@ -67,7 +67,7 @@ func TestSingleQuery(t *testing.T) {
 	t.Skip()
 
 	harness := newDoltHarness(t)
-	//harness.Setup(setup.MydbData, setup.MytableData)
+	harness.Setup(setup.MydbData, setup.MytableData)
 	engine, err := harness.NewEngine(t)
 	if err != nil {
 		panic(err)
@@ -433,6 +433,22 @@ func TestDoltUserPrivileges(t *testing.T) {
 	}
 }
 
+func TestMergeJoins(t *testing.T) {
+	if types.IsFormat_LD(types.Format_Default) {
+		t.Skip("LD keyless indexes are not sorted")
+	}
+
+	enginetest.TestMergeJoins(t, newDoltHarness(t))
+}
+
+func TestMergeJoinsPrepared(t *testing.T) {
+	if types.IsFormat_LD(types.Format_Default) {
+		t.Skip("LD keyless indexes are not sorted")
+	}
+
+	enginetest.TestMergeJoins(t, newDoltHarness(t))
+}
+
 func TestJoinQueries(t *testing.T) {
 	enginetest.TestJoinQueries(t, newDoltHarness(t))
 }
@@ -786,6 +802,12 @@ func TestDoltRevisionDbScripts(t *testing.T) {
 				Query:    "use mydb/" + commithash,
 				Expected: []sql.Row{},
 			},
+			{
+				Query: "select active_branch();",
+				Expected: []sql.Row{
+					{nil},
+				},
+			},
 			{
 				Query:    "select database();",
 				Expected: []sql.Row{{"mydb/" + commithash}},
@@ -984,7 +1006,7 @@ func TestDoltReset(t *testing.T) {
 }
 
 func TestDoltGC(t *testing.T) {
-	// TODO: This does not work because `db.chunkStore().(chunks.TableFileStore)`
+	// TODO: This does not work because `db.chunkStore().(nbs.TableFileStore)`
 	// returns not ok in PruneTableFiles
 	t.Skip()
 	for _, script := range DoltGC {
@@ -1286,7 +1308,7 @@ func TestDiffSystemTablePrepared(t *testing.T) {
 	}
 }
 
-func TestTestReadOnlyDatabases(t *testing.T) {
+func TestReadOnlyDatabases(t *testing.T) {
 	enginetest.TestReadOnlyDatabases(t, newDoltHarness(t))
 }
 
