@@ -83,18 +83,18 @@ func TestReplicationBranches(t *testing.T) {
 	}
 
 	for _, tt := range tests {
-		remoteRefs := make([]ref.DoltRef, len(tt.remote))
+		remoteRefs := make([]doltdb.RefWithHash, len(tt.remote))
 		for i := range tt.remote {
-			remoteRefs[i] = ref.NewRemoteRef("", tt.remote[i])
+			remoteRefs[i] = doltdb.RefWithHash{Ref: ref.NewRemoteRef("", tt.remote[i])}
 		}
-		localRefs := make([]ref.DoltRef, len(tt.local))
+		localRefs := make([]doltdb.RefWithHash, len(tt.local))
 		for i := range tt.local {
-			localRefs[i] = ref.NewBranchRef(tt.local[i])
+			localRefs[i] = doltdb.RefWithHash{Ref: ref.NewBranchRef(tt.local[i])}
 		}
-		diff := branchesToDelete(remoteRefs, localRefs)
+		diff := refsToDelete(remoteRefs, localRefs)
 		diffNames := make([]string, len(diff))
 		for i := range diff {
-			diffNames[i] = diff[i].GetPath()
+			diffNames[i] = diff[i].Ref.GetPath()
 		}
 		assert.Equal(t, diffNames, tt.expToDelete)
 	}
