@@ -256,11 +256,13 @@ func TestCreateTable(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			ctx := context.Background()
-			dEnv := CreateEmptyTestDatabase(t)
+			dEnv, err := CreateEmptyTestDatabase()
+			require.NoError(t, err)
+
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
 
-			updatedRoot, err := ExecuteSql(t, dEnv, root, tt.query)
+			updatedRoot, err := ExecuteSql(dEnv, root, tt.query)
 			if tt.expectedErr == "" {
 				require.NoError(t, err)
 			} else {
@@ -329,11 +331,13 @@ func TestDropTable(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			ctx := context.Background()
-			dEnv := CreateTestDatabase(t)
+			dEnv, err := CreateTestDatabase()
+			require.NoError(t, err)
+
 			root, err := dEnv.WorkingRoot(ctx)
 			require.NoError(t, err)
 
-			updatedRoot, err := ExecuteSql(t, dEnv, root, tt.query)
+			updatedRoot, err := ExecuteSql(dEnv, root, tt.query)
 
 			if tt.expectedErr == "" {
 				require.NoError(t, err)
@@ -366,42 +370,42 @@ func TestAddColumn(t *testing.T) {
 			query: "alter table people add (newColumn varchar(80))",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumn(t, "newColumn", 4208, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false)),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 4208, nil),
+			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add float column without default",
 			query: "alter table people add (newColumn float)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumn(t, "newColumn", 4208, sql.Float32, false)),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 4208, nil),
+			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add uint column without default",
 			query: "alter table people add (newColumn bigint unsigned)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumn(t, "newColumn", 4208, sql.Uint64, false)),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 4208, nil),
+			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add int column default",
 			query: "alter table people add (newColumn int default 2)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 2803, sql.Int32, false, "2")),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 2803, types.Int(int32(2))),
+			expectedRows: addColToRows(t, AllPeopleRows, 2803, types.Int(int32(2))),
 		},
 		{
 			name:  "alter add uint column default",
 			query: "alter table people add (newColumn bigint unsigned default 20)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 517, sql.Uint64, false, "20")),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 517, types.Uint(uint64(20))),
+			expectedRows: addColToRows(t, AllPeopleRows, 517, types.Uint(uint64(20))),
 		},
 		{
 			name:  "alter add string column with default",
 			query: "alter table people add (newColumn varchar(80) default 'hi')",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'hi'`)),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 13690, types.String("hi")),
+			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("hi")),
 		},
 		{
 			name:  "alter add column first",
@@ -417,7 +421,7 @@ func TestAddColumn(t *testing.T) {
 				schema.NewColumn("uuid", UuidTag, types.StringKind, false),
 				schema.NewColumn("num_episodes", NumEpisodesTag, types.UintKind, false),
 			),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 4208, nil),
+			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add column middle",
@@ -433,28 +437,28 @@ func TestAddColumn(t *testing.T) {
 				schema.NewColumn("uuid", UuidTag, types.StringKind, false),
 				schema.NewColumn("num_episodes", NumEpisodesTag, types.UintKind, false),
 			),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 4208, nil),
+			expectedRows: addColToRows(t, AllPeopleRows, 4208, nil),
 		},
 		{
 			name:  "alter add column not null",
 			query: "alter table people add (newColumn varchar(80) not null default 'default')",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, `'default'`, schema.NotNullConstraint{})),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 13690, types.String("default")),
+			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("default")),
 		},
 		{
 			name:  "alter add column not null with expression default",
 			query: "alter table people add (newColumn int not null default (2+2/2))",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 2803, sql.Int32, false, "((2 + (2 / 2)))", schema.NotNullConstraint{})),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 2803, types.Int(3)),
+			expectedRows: addColToRows(t, AllPeopleRows, 2803, types.Int(3)),
 		},
 		{
 			name:  "alter add column not null with negative expression",
 			query: "alter table people add (newColumn float not null default -1.1)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 12469, sql.Float32, false, "-1.1", schema.NotNullConstraint{})),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 12469, types.Float(float32(-1.1))),
+			expectedRows: addColToRows(t, AllPeopleRows, 12469, types.Float(float32(-1.1))),
 		},
 		{
 			name:        "alter add column not null with type mismatch in default",
@@ -476,7 +480,7 @@ func TestAddColumn(t *testing.T) {
 			query: "alter table people add (newColumn varchar(80) not null)",
 			expectedSchema: dtestutils.AddColumnToSchema(PeopleTestSchema,
 				schemaNewColumnWDefVal(t, "newColumn", 13690, sql.MustCreateStringWithDefaults(sqltypes.VarChar, 80), false, "", schema.NotNullConstraint{})),
-			expectedRows: dtestutils.AddColToRows(t, AllPeopleRows, 13690, types.String("")),
+			expectedRows: addColToRows(t, AllPeopleRows, 13690, types.String("")),
 		},
 		{
 			name:  "alter add column nullable",
@@ -501,11 +505,14 @@ func TestAddColumn(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			dEnv := CreateTestDatabase(t)
-			ctx := context.Background()
-			root, _ := dEnv.WorkingRoot(ctx)
+			dEnv, err := CreateTestDatabase()
+			require.NoError(t, err)
 
-			updatedRoot, err := ExecuteSql(t, dEnv, root, tt.query)
+			ctx := context.Background()
+			root, err := dEnv.WorkingRoot(ctx)
+			require.NoError(t, err)
+
+			updatedRoot, err := ExecuteSql(dEnv, root, tt.query)
 
 			if tt.expectedErr == "" {
 				require.NoError(t, err)
@@ -619,11 +626,13 @@ func TestRenameColumn(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			dEnv := CreateTestDatabase(t)
+			dEnv, err := CreateTestDatabase()
+			require.NoError(t, err)
+
 			ctx := context.Background()
 			root, _ := dEnv.WorkingRoot(ctx)
 
-			updatedRoot, err := ExecuteSql(t, dEnv, root, tt.query)
+			updatedRoot, err := ExecuteSql(dEnv, root, tt.query)
 
 			if tt.expectedErr == "" {
 				require.NoError(t, err)
@@ -732,11 +741,14 @@ func TestRenameTableStatements(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			dEnv := CreateTestDatabase(t)
-			ctx := context.Background()
-			root, _ := dEnv.WorkingRoot(ctx)
+			dEnv, err := CreateTestDatabase()
+			require.NoError(t, err)
 
-			updatedRoot, err := ExecuteSql(t, dEnv, root, tt.query)
+			ctx := context.Background()
+			root, err := dEnv.WorkingRoot(ctx)
+			require.NoError(t, err)
+
+			updatedRoot, err := ExecuteSql(dEnv, root, tt.query)
 			if len(tt.expectedErr) > 0 {
 				require.Error(t, err)
 				assert.Contains(t, err.Error(), tt.expectedErr)
@@ -786,10 +798,16 @@ func TestAlterSystemTables(t *testing.T) {
 	reservedTableNames := []string{"dolt_schemas", "dolt_query_catalog"}
 
 	var dEnv *env.DoltEnv
+	var err error
 	setup := func() {
-		dEnv = CreateTestDatabase(t)
-		dtestutils.CreateEmptyTestTable(t, dEnv, "dolt_docs", doltdb.DocsSchema)
-		dtestutils.CreateEmptyTestTable(t, dEnv, doltdb.SchemasTableName, SchemasTableSchema())
+		dEnv, err = CreateTestDatabase()
+		require.NoError(t, err)
+
+		err := CreateEmptyTestTable(dEnv, "dolt_docs", doltdb.DocsSchema)
+		require.NoError(t, err)
+
+		err = CreateEmptyTestTable(dEnv, doltdb.SchemasTableName, SchemasTableSchema())
+		require.NoError(t, err)
 
 		CreateTestTable(t, dEnv, "dolt_docs", doltdb.DocsSchema,
 			"INSERT INTO dolt_docs VALUES ('LICENSE.md','A license')")
@@ -1071,7 +1089,7 @@ func TestIndexOverwrite(t *testing.T) {
 	if err != nil {
 		panic(err)
 	}
-	root, err = ExecuteSql(t, dEnv, root, `
+	root, err = ExecuteSql(dEnv, root, `
 CREATE TABLE parent (
   pk bigint PRIMARY KEY,
   v1 bigint,
@@ -1110,13 +1128,13 @@ INSERT INTO child_non_unq VALUES ('1', 1), ('2', NULL), ('3', 3), ('4', 3), ('5'
 `)
 	// test index creation
 	require.NoError(t, err)
-	root, err = ExecuteSql(t, dEnv, root, "CREATE INDEX abc ON child (parent_value);")
+	root, err = ExecuteSql(dEnv, root, "CREATE INDEX abc ON child (parent_value);")
 	require.NoError(t, err)
-	_, err = ExecuteSql(t, dEnv, root, "CREATE INDEX abc_idx ON child_idx (parent_value);")
+	_, err = ExecuteSql(dEnv, root, "CREATE INDEX abc_idx ON child_idx (parent_value);")
 	require.NoError(t, err)
-	root, err = ExecuteSql(t, dEnv, root, "CREATE UNIQUE INDEX abc_unq ON child_unq (parent_value);")
+	root, err = ExecuteSql(dEnv, root, "CREATE UNIQUE INDEX abc_unq ON child_unq (parent_value);")
 	require.NoError(t, err)
-	_, err = ExecuteSql(t, dEnv, root, "CREATE UNIQUE INDEX abc_non_unq ON child_non_unq (parent_value);")
+	_, err = ExecuteSql(dEnv, root, "CREATE UNIQUE INDEX abc_non_unq ON child_non_unq (parent_value);")
 	if assert.Error(t, err) {
 		assert.Contains(t, err.Error(), "duplicate unique key given")
 	}
@@ -1138,43 +1156,154 @@ INSERT INTO child_non_unq VALUES ('1', 1), ('2', NULL), ('3', 3), ('4', 3), ('5'
 	require.Equal(t, "parent_value", fkChildNonUnq.TableIndex)
 
 	// insert tests against index
-	root, err = ExecuteSql(t, dEnv, root, "INSERT INTO child VALUES ('6', 5)")
+	root, err = ExecuteSql(dEnv, root, "INSERT INTO child VALUES ('6', 5)")
 	require.NoError(t, err)
-	root, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_idx VALUES ('6', 5)")
+	root, err = ExecuteSql(dEnv, root, "INSERT INTO child_idx VALUES ('6', 5)")
 	require.NoError(t, err)
-	_, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_unq VALUES ('6', 5)")
+	_, err = ExecuteSql(dEnv, root, "INSERT INTO child_unq VALUES ('6', 5)")
 	if assert.Error(t, err) {
 		assert.True(t, sql.ErrUniqueKeyViolation.Is(err.(sql.WrappedInsertError).Cause))
 	}
-	root, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_non_unq VALUES ('6', 5)")
+	root, err = ExecuteSql(dEnv, root, "INSERT INTO child_non_unq VALUES ('6', 5)")
 	require.NoError(t, err)
 
 	// insert tests against foreign key
-	_, err = ExecuteSql(t, dEnv, root, "INSERT INTO child VALUES ('9', 9)")
+	_, err = ExecuteSql(dEnv, root, "INSERT INTO child VALUES ('9', 9)")
 	if assert.Error(t, err) {
 		assert.Contains(t, err.Error(), "Foreign key violation")
 	}
-	_, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_idx VALUES ('9', 9)")
+	_, err = ExecuteSql(dEnv, root, "INSERT INTO child_idx VALUES ('9', 9)")
 	if assert.Error(t, err) {
 		assert.Contains(t, err.Error(), "Foreign key violation")
 	}
-	_, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_unq VALUES ('9', 9)")
+	_, err = ExecuteSql(dEnv, root, "INSERT INTO child_unq VALUES ('9', 9)")
 	if assert.Error(t, err) {
 		assert.Contains(t, err.Error(), "Foreign key violation")
 	}
-	_, err = ExecuteSql(t, dEnv, root, "INSERT INTO child_non_unq VALUES ('9', 9)")
+	_, err = ExecuteSql(dEnv, root, "INSERT INTO child_non_unq VALUES ('9', 9)")
 	if assert.Error(t, err) {
 		assert.Contains(t, err.Error(), "Foreign key violation")
 	}
 }
 
+func TestDropPrimaryKey(t *testing.T) {
+	ctx := context.Background()
+	dEnv := dtestutils.CreateTestEnv()
+	root, err := dEnv.WorkingRoot(ctx)
+	if err != nil {
+		panic(err)
+	}
+
+	t.Run("drop primary key", func(t *testing.T) {
+		// setup
+		root, err = ExecuteSql(dEnv, root, "create table parent (i int, j int, k int, index i (i), index ij (i, j), index ijk (i, j, k), index j (j), index kji (k, j, i));")
+		require.NoError(t, err)
+		root, err = ExecuteSql(dEnv, root, "create table child (x int, y int, constraint fk_child foreign key (x, y) references parent (i, j));")
+		require.NoError(t, err)
+
+		// check foreign keys for updated index
+		fkc, err := root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok := fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "xy", fkChild.TableIndex)
+		require.Equal(t, "ij", fkChild.ReferencedTableIndex)
+
+		// add primary key
+		root, err = ExecuteSql(dEnv, root, "alter table parent add primary key (i, j);")
+		require.NoError(t, err)
+
+		// dropping secondary index ij, should choose ijk
+		root, err = ExecuteSql(dEnv, root, "alter table parent drop index ij;")
+		require.NoError(t, err)
+
+		// check foreign keys for updated index
+		fkc, err = root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok = fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "xy", fkChild.TableIndex)
+		require.Equal(t, "ijk", fkChild.ReferencedTableIndex)
+
+		// dropping secondary index ijk, should switch to primary key
+		root, err = ExecuteSql(dEnv, root, "alter table parent drop index ijk;")
+		require.NoError(t, err)
+
+		// check foreign keys for updated index
+		fkc, err = root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok = fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "xy", fkChild.TableIndex)
+		require.Equal(t, "", fkChild.ReferencedTableIndex)
+
+		// no viable secondary indexes left, should be unable to drop primary key
+		_, err = ExecuteSql(dEnv, root, "alter table parent drop primary key;")
+		require.Error(t, err)
+	})
+}
+
+func TestDropIndex(t *testing.T) {
+	ctx := context.Background()
+	dEnv := dtestutils.CreateTestEnv()
+	root, err := dEnv.WorkingRoot(ctx)
+	if err != nil {
+		panic(err)
+	}
+	t.Run("drop secondary indexes", func(t *testing.T) {
+		// setup
+		root, err = ExecuteSql(dEnv, root, "create table parent (i int);")
+		require.NoError(t, err)
+		root, err = ExecuteSql(dEnv, root, "alter table parent add index idx1 (i);")
+		require.NoError(t, err)
+		root, err = ExecuteSql(dEnv, root, "alter table parent add index idx2 (i);")
+		require.NoError(t, err)
+		root, err = ExecuteSql(dEnv, root, "alter table parent add index idx3 (i);")
+		require.NoError(t, err)
+		root, err = ExecuteSql(dEnv, root, "create table child (j int, constraint fk_child foreign key (j) references parent (i));")
+		require.NoError(t, err)
+
+		// drop and check next index
+		fkc, err := root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok := fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "j", fkChild.TableIndex)
+		require.Equal(t, "idx1", fkChild.ReferencedTableIndex)
+
+		// dropping secondary index, should switch to existing index
+		root, err = ExecuteSql(dEnv, root, "alter table parent drop index idx1;")
+		require.NoError(t, err)
+		fkc, err = root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok = fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "j", fkChild.TableIndex)
+		require.Equal(t, "idx2", fkChild.ReferencedTableIndex)
+
+		// dropping secondary index, should switch to existing index
+		root, err = ExecuteSql(dEnv, root, "alter table parent drop index idx2;")
+		require.NoError(t, err)
+		fkc, err = root.GetForeignKeyCollection(ctx)
+		require.NoError(t, err)
+		fkChild, ok = fkc.GetByNameCaseInsensitive("fk_child")
+		require.True(t, ok)
+		require.Equal(t, "j", fkChild.TableIndex)
+		require.Equal(t, "idx3", fkChild.ReferencedTableIndex)
+
+		// dropping secondary index, should fail since there are no indexes to replace it
+		_, err = ExecuteSql(dEnv, root, "alter table parent drop index idx3;")
+		require.Error(t, err)
+	})
+}
+
 func TestCreateIndexUnique(t *testing.T) {
 	dEnv := dtestutils.CreateTestEnv()
 	root, err := dEnv.WorkingRoot(context.Background())
 	if err != nil {
 		panic(err)
 	}
-	root, err = ExecuteSql(t, dEnv, root, `
+	root, err = ExecuteSql(dEnv, root, `
 CREATE TABLE pass_unique (
   pk1 BIGINT PRIMARY KEY,
   v1 BIGINT,
@@ -1189,9 +1318,9 @@ INSERT INTO pass_unique VALUES (1, 1, 1), (2, 2, 2), (3, 3, 3);
 INSERT INTO fail_unique VALUES (1, 1, 1), (2, 2, 2), (3, 2, 3);
 `)
 	require.NoError(t, err)
-	root, err = ExecuteSql(t, dEnv, root, "CREATE UNIQUE INDEX idx_v1 ON pass_unique(v1)")
+	root, err = ExecuteSql(dEnv, root, "CREATE UNIQUE INDEX idx_v1 ON pass_unique(v1)")
 	assert.NoError(t, err)
-	root, err = ExecuteSql(t, dEnv, root, "CREATE UNIQUE INDEX idx_v1 ON fail_unique(v1)")
+	root, err = ExecuteSql(dEnv, root, "CREATE UNIQUE INDEX idx_v1 ON fail_unique(v1)")
 	if assert.Error(t, err) {
 		assert.Contains(t, strings.ToLower(err.Error()), "unique")
 	}
@@ -1200,7 +1329,7 @@ INSERT INTO fail_unique VALUES (1, 1, 1), (2, 2, 2), (3, 2, 3);
 func assertFails(t *testing.T, dEnv *env.DoltEnv, query, expectedErr string) {
 	ctx := context.Background()
 	root, _ := dEnv.WorkingRoot(ctx)
-	_, err := ExecuteSql(t, dEnv, root, query)
+	_, err := ExecuteSql(dEnv, root, query)
 	require.Error(t, err, query)
 	assert.Contains(t, err.Error(), expectedErr)
 }
@@ -1208,6 +1337,6 @@ func assertFails(t *testing.T, dEnv *env.DoltEnv, query, expectedErr string) {
 func assertSucceeds(t *testing.T, dEnv *env.DoltEnv, query string) {
 	ctx := context.Background()
 	root, _ := dEnv.WorkingRoot(ctx)
-	_, err := ExecuteSql(t, dEnv, root, query)
+	_, err := ExecuteSql(dEnv, root, query)
 	assert.NoError(t, err, query)
 }
