@@ -15,12 +15,14 @@
 package sqle
 
 import (
-	"github.com/dolthub/go-mysql-server/sql"
+	"context"
 
-	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
+	"github.com/dolthub/go-mysql-server/sql"
 
 	"github.com/dolthub/dolt/go/libraries/doltcore/doltdb"
 	"github.com/dolthub/dolt/go/libraries/doltcore/env"
+	"github.com/dolthub/dolt/go/libraries/doltcore/sqle/dsess"
+	"github.com/dolthub/dolt/go/libraries/doltcore/table/editor"
 )
 
 // UserSpaceDatabase in an implementation of sql.Database for root values. Does not expose any of the internal dolt tables.
@@ -76,6 +78,10 @@ func (db *UserSpaceDatabase) GetTableNames(ctx *sql.Context) ([]string, error) {
 	return resultingTblNames, nil
 }
 
+func (db *UserSpaceDatabase) InitialDBState(ctx context.Context, branch string) (dsess.InitialDbState, error) {
+	return getInitialDBStateForUserSpaceDb(ctx, db)
+}
+
 func (db *UserSpaceDatabase) GetRoot(*sql.Context) (*doltdb.RootValue, error) {
 	return db.RootValue, nil
 }
@@ -88,14 +94,10 @@ func (db *UserSpaceDatabase) DbData() env.DbData {
 	panic("UserSpaceDatabase does not have dbdata")
 }
 
-func (db *UserSpaceDatabase) StartTransaction(ctx *sql.Context, tCharacteristic sql.TransactionCharacteristic) (sql.Transaction, error) {
-	panic("UserSpaceDatabase does not support transactions")
-}
-
 func (db *UserSpaceDatabase) Flush(ctx *sql.Context) error {
 	panic("UserSpaceDatabase cannot flush")
 }
 
 func (db *UserSpaceDatabase) EditOptions() editor.Options {
-	return editor.Options{}
+	return db.editOpts
 }
