@@ -19,7 +19,7 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/google/uuid"
+	"github.com/dolthub/go-mysql-server/sql"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
@@ -40,9 +40,7 @@ func (*StringBuilderCloser) Close() error {
 }
 
 func TestEndToEnd(t *testing.T) {
-	id := uuid.MustParse("00000000-0000-0000-0000-000000000000")
 	tableName := "people"
-
 	dropCreateStatement := sqlfmt.DropTableIfExistsStmt(tableName) + "\n" +
 		"CREATE TABLE `people` (\n" +
 		"  `id` varchar(16383) NOT NULL,\n" +
@@ -55,9 +53,12 @@ func TestEndToEnd(t *testing.T) {
 		"  CONSTRAINT `test-check` CHECK ((`age` < 123))\n" +
 		") ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_bin;"
 
+	sch, err := dtestutils.Schema()
+	require.NoError(t, err)
+
 	type test struct {
 		name           string
-		rows           []row.Row
+		rows           []sql.Row
 		sch            schema.Schema
 		expectedOutput string
 	}
@@ -65,10 +66,11 @@ func TestEndToEnd(t *testing.T) {
 	tests := []test{
 		{
 			name: "two rows",
-			rows: rs(
-				dtestutils.NewTypedRow(id, "some guy", 100, false, strPointer("normie")),
-				dtestutils.NewTypedRow(id, "guy personson", 0, true, strPointer("officially a person"))),
-			sch: dtestutils.TypedSchema,
+			rows: []sql.Row{
+				{"00000000-0000-0000-0000-000000000000", "some guy", 100, 0, "normie"},
+				{"00000000-0000-0000-0000-000000000000", "guy personson", 0, 1, "officially a person"},
+			},
+			sch: sch,
 			expectedOutput: dropCreateStatement + "\n" +
 				"INSERT INTO `people` (`id`,`name`,`age`,`is_married`,`title`) " +
 				`VALUES ('00000000-0000-0000-0000-000000000000','some guy',100,0,'normie');` + "\n" +
@@ -77,7 +79,7 @@ func TestEndToEnd(t *testing.T) {
 		},
 		{
 			name:           "no rows",
-			sch:            dtestutils.TypedSchema,
+			sch:            sch,
 			expectedOutput: dropCreateStatement + "\n",
 		},
 	}
@@ -112,7 +114,7 @@ func TestEndToEnd(t *testing.T) {
 			}
 
 			for _, r := range tt.rows {
-				assert.NoError(t, w.WriteRow(ctx, r))
+				assert.NoError(t, w.WriteSqlRow(ctx, r))
 			}
 
 			assert.NoError(t, w.Close(ctx))
