@@ -27,6 +27,7 @@ import (
 	"fmt"
 	"sync"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -67,11 +68,9 @@ func TestChunkStoreVersion(t *testing.T) {
 func TestChunkStoreRebase(t *testing.T) {
 	assert := assert.New(t)
 	fm, p, q, store := makeStoreWithFakes(t)
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	h, err := store.Root(context.Background())
@@ -103,11 +102,9 @@ func TestChunkStoreRebase(t *testing.T) {
 func TestChunkStoreCommit(t *testing.T) {
 	assert := assert.New(t)
 	_, _, q, store := makeStoreWithFakes(t)
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	h, err := store.Root(context.Background())
@@ -151,11 +148,9 @@ func TestChunkStoreCommit(t *testing.T) {
 func TestChunkStoreManifestAppearsAfterConstruction(t *testing.T) {
 	assert := assert.New(t)
 	fm, p, q, store := makeStoreWithFakes(t)
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	h, err := store.Root(context.Background())
@@ -203,11 +198,9 @@ func TestChunkStoreManifestFirstWriteByOtherProcess(t *testing.T) {
 func TestChunkStoreCommitOptimisticLockFail(t *testing.T) {
 	assert := assert.New(t)
 	fm, p, q, store := makeStoreWithFakes(t)
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	// Simulate another process writing a manifest behind store's back.
@@ -229,9 +222,6 @@ func TestChunkStoreManifestPreemptiveOptimisticLockFail(t *testing.T) {
 	fm := &fakeManifest{}
 	mm := manifestManager{fm, newManifestCache(defaultManifestCacheSize), newManifestLocks()}
 	q := NewUnlimitedMemQuotaProvider()
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	p := newFakeTablePersister(q)
 
 	c := inlineConjoiner{defaultMaxTables}
@@ -240,6 +230,7 @@ func TestChunkStoreManifestPreemptiveOptimisticLockFail(t *testing.T) {
 	require.NoError(t, err)
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	// Simulate another goroutine writing a manifest behind store's back.
@@ -281,9 +272,6 @@ func TestChunkStoreCommitLocksOutFetch(t *testing.T) {
 	upm := &updatePreemptManifest{manifest: fm}
 	mm := manifestManager{upm, newManifestCache(defaultManifestCacheSize), newManifestLocks()}
 	q := NewUnlimitedMemQuotaProvider()
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	p := newFakeTablePersister(q)
 	c := inlineConjoiner{defaultMaxTables}
 
@@ -291,6 +279,7 @@ func TestChunkStoreCommitLocksOutFetch(t *testing.T) {
 	require.NoError(t, err)
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	// store.Commit() should lock out calls to mm.Fetch()
@@ -301,7 +290,7 @@ func TestChunkStoreCommitLocksOutFetch(t *testing.T) {
 		go func() {
 			defer wg.Done()
 			var err error
-			_, fetched, err = mm.Fetch(context.Background(), nil)
+			_, fetched, _, err = mm.Fetch(context.Background(), nil)
 			require.NoError(t, err)
 		}()
 	}
@@ -328,9 +317,6 @@ func TestChunkStoreSerializeCommits(t *testing.T) {
 	mc := newManifestCache(defaultManifestCacheSize)
 	l := newManifestLocks()
 	q := NewUnlimitedMemQuotaProvider()
-	defer func() {
-		require.EqualValues(t, 0, q.Usage())
-	}()
 	p := newFakeTablePersister(q)
 
 	c := inlineConjoiner{defaultMaxTables}
@@ -339,6 +325,7 @@ func TestChunkStoreSerializeCommits(t *testing.T) {
 	require.NoError(t, err)
 	defer func() {
 		require.NoError(t, store.Close())
+		require.EqualValues(t, 0, q.Usage())
 	}()
 
 	storeChunk := chunks.NewChunk([]byte("store"))
@@ -408,12 +395,15 @@ func interloperWrite(fm *fakeManifest, p tablePersister, rootChunk []byte, chunk
 
 	var src chunkSource
 	src, err = p.Persist(context.Background(), createMemTable(persisted), nil, &Stats{})
-
 	if err != nil {
 		return hash.Hash{}, nil, err
 	}
 
-	fm.set(constants.NomsVersion, newLock, newRoot, []tableSpec{{mustAddr(src.hash()), uint32(len(chunks) + 1)}}, nil)
+	fm.set(constants.NomsVersion, newLock, newRoot, []tableSpec{{src.hash(), uint32(len(chunks) + 1)}}, nil)
+
+	if err = src.close(); err != nil {
+		return [20]byte{}, nil, err
+	}
 	return
 }
 
@@ -497,12 +487,12 @@ func newFakeTableSet(q MemoryQuotaProvider) tableSet {
 }
 
 func newFakeTablePersister(q MemoryQuotaProvider) fakeTablePersister {
-	return fakeTablePersister{q, map[addr]tableReader{}, map[addr]bool{}, map[addr]bool{}, &sync.RWMutex{}}
+	return fakeTablePersister{q, map[addr][]byte{}, map[addr]bool{}, map[addr]bool{}, &sync.RWMutex{}}
 }
 
 type fakeTablePersister struct {
 	q             MemoryQuotaProvider
-	sources       map[addr]tableReader
+	sources       map[addr][]byte
 	sourcesToFail map[addr]bool
 	opened        map[addr]bool
 	mu            *sync.RWMutex
@@ -511,57 +501,55 @@ type fakeTablePersister struct {
 var _ tablePersister = fakeTablePersister{}
 
 func (ftp fakeTablePersister) Persist(ctx context.Context, mt *memTable, haver chunkReader, stats *Stats) (chunkSource, error) {
-	if mustUint32(mt.count()) > 0 {
-		name, data, chunkCount, err := mt.write(haver, stats)
-
-		if err != nil {
-			return emptyChunkSource{}, err
-		}
-
-		if chunkCount > 0 {
-			ftp.mu.Lock()
-			defer ftp.mu.Unlock()
-			ti, err := parseTableIndexByCopy(data, ftp.q)
-
-			if err != nil {
-				return nil, err
-			}
-
-			s, err := newTableReader(ti, tableReaderAtFromBytes(data), fileBlockSize)
-			if err != nil {
-				return emptyChunkSource{}, err
-			}
-			ftp.sources[name] = s
-			return chunkSourceAdapter{ftp.sources[name], name}, nil
-		}
+	if mustUint32(mt.count()) == 0 {
+		return emptyChunkSource{}, nil
 	}
-	return emptyChunkSource{}, nil
-}
 
-func (ftp fakeTablePersister) ConjoinAll(ctx context.Context, sources chunkSources, stats *Stats) (chunkSource, error) {
-	name, data, chunkCount, err := compactSourcesToBuffer(sources)
+	name, data, chunkCount, err := mt.write(haver, stats)
+	if err != nil {
+		return emptyChunkSource{}, err
+	} else if chunkCount == 0 {
+		return emptyChunkSource{}, nil
+	}
 
+	ftp.mu.Lock()
+	ftp.sources[name] = data
+	ftp.mu.Unlock()
+
+	ti, err := parseTableIndexByCopy(ctx, data, ftp.q)
 	if err != nil {
 		return nil, err
 	}
 
-	if chunkCount > 0 {
-		ftp.mu.Lock()
-		defer ftp.mu.Unlock()
-		ti, err := parseTableIndexByCopy(data, ftp.q)
-
-		if err != nil {
-			return nil, err
-		}
-
-		s, err := newTableReader(ti, tableReaderAtFromBytes(data), fileBlockSize)
-		if err != nil {
-			return nil, err
-		}
-		ftp.sources[name] = s
-		return chunkSourceAdapter{ftp.sources[name], name}, nil
+	cs, err := newTableReader(ti, tableReaderAtFromBytes(data), fileBlockSize)
+	if err != nil {
+		return emptyChunkSource{}, err
 	}
-	return emptyChunkSource{}, nil
+	return chunkSourceAdapter{cs, name}, nil
+}
+
+func (ftp fakeTablePersister) ConjoinAll(ctx context.Context, sources chunkSources, stats *Stats) (chunkSource, error) {
+	name, data, chunkCount, err := compactSourcesToBuffer(sources)
+	if err != nil {
+		return nil, err
+	} else if chunkCount == 0 {
+		return emptyChunkSource{}, nil
+	}
+
+	ftp.mu.Lock()
+	defer ftp.mu.Unlock()
+	ftp.sources[name] = data
+
+	ti, err := parseTableIndexByCopy(ctx, data, ftp.q)
+	if err != nil {
+		return nil, err
+	}
+
+	cs, err := newTableReader(ti, tableReaderAtFromBytes(data), fileBlockSize)
+	if err != nil {
+		return nil, err
+	}
+	return chunkSourceAdapter{cs, name}, nil
 }
 
 func compactSourcesToBuffer(sources chunkSources) (name addr, data []byte, chunkCount uint32, err error) {
@@ -579,18 +567,20 @@ func compactSourcesToBuffer(sources chunkSources) (name addr, data []byte, chunk
 	tw := newTableWriter(buff, nil)
 	errString := ""
 
+	ctx := context.Background()
 	for _, src := range sources {
-		chunks := make(chan extractRecord)
+		ch := make(chan extractRecord)
 		go func() {
-			defer close(chunks)
-			err := src.extract(context.Background(), chunks)
-
+			defer close(ch)
+			err = extractAllChunks(ctx, src, func(rec extractRecord) {
+				ch <- rec
+			})
 			if err != nil {
-				chunks <- extractRecord{a: mustAddr(src.hash()), err: err}
+				ch <- extractRecord{a: src.hash(), err: err}
 			}
 		}()
 
-		for rec := range chunks {
+		for rec := range ch {
 			if rec.err != nil {
 				errString += fmt.Sprintf("Failed to extract %s:\n %v\n******\n\n", rec.a, rec.err)
 				continue
@@ -615,13 +605,58 @@ func compactSourcesToBuffer(sources chunkSources) (name addr, data []byte, chunk
 func (ftp fakeTablePersister) Open(ctx context.Context, name addr, chunkCount uint32, stats *Stats) (chunkSource, error) {
 	ftp.mu.Lock()
 	defer ftp.mu.Unlock()
+
 	if _, ok := ftp.sourcesToFail[name]; ok {
 		return nil, errors.New("intentional failure")
 	}
+	data := ftp.sources[name]
 	ftp.opened[name] = true
-	return chunkSourceAdapter{ftp.sources[name], name}, nil
+
+	ti, err := parseTableIndexByCopy(ctx, data, ftp.q)
+	if err != nil {
+		return nil, err
+	}
+
+	cs, err := newTableReader(ti, tableReaderAtFromBytes(data), fileBlockSize)
+	if err != nil {
+		return emptyChunkSource{}, err
+	}
+	return chunkSourceAdapter{cs, name}, nil
 }
 
-func (ftp fakeTablePersister) PruneTableFiles(_ context.Context, _ manifestContents) error {
+func (ftp fakeTablePersister) Exists(ctx context.Context, name addr, chunkCount uint32, stats *Stats) (bool, error) {
+	if _, ok := ftp.sourcesToFail[name]; ok {
+		return false, errors.New("intentional failure")
+	}
+	return true, nil
+}
+
+func (ftp fakeTablePersister) PruneTableFiles(_ context.Context, _ manifestContents, _ time.Time) error {
 	return chunks.ErrUnsupportedOperation
 }
+
+func (ftp fakeTablePersister) Close() error {
+	return nil
+}
+
+func extractAllChunks(ctx context.Context, src chunkSource, cb func(rec extractRecord)) (err error) {
+	var index tableIndex
+	if index, err = src.index(); err != nil {
+		return err
+	}
+
+	var a addr
+	for i := uint32(0); i < index.chunkCount(); i++ {
+		_, err = index.indexEntry(i, &a)
+		if err != nil {
+			return err
+		}
+
+		data, err := src.get(ctx, a, nil)
+		if err != nil {
+			return err
+		}
+		cb(extractRecord{a: a, data: data})
+	}
+	return
+}
