@@ -28,7 +28,9 @@ import (
 const (
 	// This constant is mirrored from serial.AddressMap.KeyOffsetsLength()
 	// It is only as stable as the flatbuffers schema that defines it.
-	addressMapKeyOffsetsVOffset = 6
+	addressMapKeyItemsBytesVOffset   fb.VOffsetT = 4
+	addressMapKeyItemsOffsetsVOffset fb.VOffsetT = 6
+	addressMapAddressArrayVOffset    fb.VOffsetT = 8
 )
 
 var addressMapFileID = []byte(serial.AddressMapFileID)
@@ -81,25 +83,28 @@ func (s AddressMapSerializer) Serialize(keys, addrs [][]byte, subtrees []uint64,
 	return serial.FinishMessage(b, serial.AddressMapEnd(b), addressMapFileID)
 }
 
-func getAddressMapKeys(msg serial.Message) (keys ItemArray, err error) {
+func getAddressMapKeys(msg serial.Message) (keys ItemAccess, err error) {
 	var am serial.AddressMap
 	err = serial.InitAddressMapRoot(&am, msg, serial.MessagePrefixSz)
 	if err != nil {
 		return keys, err
 	}
-	keys.Items = am.KeyItemsBytes()
-	keys.Offs = getAddressMapKeyOffsets(&am)
+	keys.bufStart = lookupVectorOffset(addressMapKeyItemsBytesVOffset, am.Table())
+	keys.bufLen = uint16(am.KeyItemsLength())
+	keys.offStart = lookupVectorOffset(addressMapKeyItemsOffsetsVOffset, am.Table())
+	keys.offLen = uint16(am.KeyOffsetsLength() * uint16Size)
 	return
 }
 
-func getAddressMapValues(msg serial.Message) (values ItemArray, err error) {
+func getAddressMapValues(msg serial.Message) (values ItemAccess, err error) {
 	var am serial.AddressMap
 	err = serial.InitAddressMapRoot(&am, msg, serial.MessagePrefixSz)
 	if err != nil {
 		return values, err
 	}
-	values.Items = am.AddressArrayBytes()
-	values.Offs = offsetsForAddressArray(values.Items)
+	values.bufStart = lookupVectorOffset(addressMapAddressArrayVOffset, am.Table())
+	values.bufLen = uint16(am.AddressArrayLength())
+	values.itemWidth = hash.ByteLen
 	return
 }
 
@@ -128,13 +133,13 @@ func getAddressMapCount(msg serial.Message) (uint16, error) {
 	return uint16(am.KeyOffsetsLength() - 1), nil
 }
 
-func getAddressMapTreeLevel(msg serial.Message) (int, error) {
+func getAddressMapTreeLevel(msg serial.Message) (uint16, error) {
 	var am serial.AddressMap
 	err := serial.InitAddressMapRoot(&am, msg, serial.MessagePrefixSz)
 	if err != nil {
 		return 0, err
 	}
-	return int(am.TreeLevel()), nil
+	return uint16(am.TreeLevel()), nil
 }
 
 func getAddressMapTreeCount(msg serial.Message) (int, error) {
@@ -160,15 +165,6 @@ func getAddressMapSubtrees(msg serial.Message) ([]uint64, error) {
 	return decodeVarints(am.SubtreeCountsBytes(), counts), nil
 }
 
-func getAddressMapKeyOffsets(pm *serial.AddressMap) []byte {
-	sz := pm.KeyOffsetsLength() * 2
-	tab := pm.Table()
-	vec := tab.Offset(addressMapKeyOffsetsVOffset)
-	start := int(tab.Vector(fb.UOffsetT(vec)))
-	stop := start + sz
-	return tab.Bytes[start:stop]
-}
-
 func estimateAddressMapSize(keys, addresses [][]byte, subtrees []uint64) (keySz, addrSz, totalSz int) {
 	assertTrue(len(keys) == len(addresses), "num keys != num addresses for AddressMap")
 	for i := range keys {
