@@ -32,8 +32,7 @@ func roundTripTreeItems(t *testing.T) {
 	root, items, ns := randomTree(t, 1000)
 	assert.NotNil(t, root)
 	assert.True(t, root.count > 0)
-	level, err := root.Level()
-	require.NoError(t, err)
+	level := root.Level()
 	assert.True(t, level > 0)
 	//assert.Equal(t, uint64(1000), root.cumulativeCount())
 	assert.Equal(t, countTree(t, ns, root), 1000)
@@ -45,8 +44,7 @@ func roundTripTreeItems(t *testing.T) {
 	root, items, ns = randomTree(t, 10_000)
 	assert.NotNil(t, root)
 	assert.True(t, root.count > 0)
-	level, err = root.Level()
-	require.NoError(t, err)
+	level = root.Level()
 	assert.True(t, level > 0)
 	//assert.Equal(t, uint64(10_000), root.cumulativeCount())
 	assert.Equal(t, countTree(t, ns, root), 10_000)
@@ -58,8 +56,7 @@ func roundTripTreeItems(t *testing.T) {
 	root, items, ns = randomTree(t, 100_000)
 	assert.NotNil(t, root)
 	assert.True(t, root.count > 0)
-	level, err = root.Level()
-	require.NoError(t, err)
+	level = root.Level()
 	assert.True(t, level > 0)
 	//assert.Equal(t, uint64(100_000), root.cumulativeCount())
 	assert.Equal(t, countTree(t, ns, root), 100_000)
