@@ -28,6 +28,7 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 
 	"github.com/dolthub/dolt/go/store/chunks"
 	"github.com/dolthub/dolt/go/store/datas"
@@ -47,8 +48,8 @@ func TestAbsolutePathToAndFromString(t *testing.T) {
 
 	h, err := types.Float(42).Hash(types.Format_Default) // arbitrary hash
 	assert.NoError(err)
-	test(fmt.Sprintf("foo.bar[#%s]", h.String()))
-	test(fmt.Sprintf("#%s.bar[42]", h.String()))
+	test(fmt.Sprintf("/refs/heads/main"))
+	test(fmt.Sprintf("#%s", h.String()))
 }
 
 func TestAbsolutePaths(t *testing.T) {
@@ -93,70 +94,25 @@ func TestAbsolutePaths(t *testing.T) {
 	}
 
 	resolvesTo(head, "ds")
-	resolvesTo(emptySet, "ds.parents")
-	resolvesTo(list, "ds.value")
-	resolvesTo(s0, "ds.value[0]")
-	resolvesTo(s1, "ds.value[1]")
 	resolvesTo(head, "#"+mustHash(head.Hash(vs.Format())).String())
 	resolvesTo(list, "#"+mustHash(list.Hash(vs.Format())).String())
 	resolvesTo(s0, "#"+mustHash(s0.Hash(vs.Format())).String())
 	resolvesTo(s1, "#"+mustHash(s1.Hash(vs.Format())).String())
-	resolvesTo(s0, "#"+mustHash(list.Hash(vs.Format())).String()+"[0]")
-	resolvesTo(s1, "#"+mustHash(list.Hash(vs.Format())).String()+"[1]")
 
 	resolvesTo(nil, "foo")
-	resolvesTo(nil, "foo.parents")
-	resolvesTo(nil, "foo.value")
-	resolvesTo(nil, "foo.value[0]")
 	resolvesTo(nil, "#"+mustHash(types.String("baz").Hash(vs.Format())).String())
 	resolvesTo(nil, "#"+mustHash(types.String("baz").Hash(vs.Format())).String()+"[0]")
 }
 
-func TestReadAbsolutePaths(t *testing.T) {
-	assert := assert.New(t)
-	storage := &chunks.MemoryStorage{}
-	cs := storage.NewView()
-	vs := types.NewValueStore(cs)
-	db := datas.NewTypesDatabase(vs, tree.NewNodeStore(cs))
-
-	s0, s1 := types.String("foo"), types.String("bar")
-	list, err := types.NewList(context.Background(), vs, s0, s1)
-	assert.NoError(err)
-
-	ds, err := db.GetDataset(context.Background(), "ds")
-	assert.NoError(err)
-	_, err = datas.CommitValue(context.Background(), db, ds, list)
-	assert.NoError(err)
-
-	vals, err := ReadAbsolutePaths(context.Background(), db, vs, "ds.value[0]", "ds.value[1]")
-	assert.NoError(err)
-
-	assert.Equal(2, len(vals))
-	assert.Equal("foo", string(vals[0].(types.String)))
-	assert.Equal("bar", string(vals[1].(types.String)))
-
-	vals, err = ReadAbsolutePaths(context.Background(), db, vs, "!!#")
-	assert.Nil(vals)
-	assert.Equal("invalid input path '!!#'", err.Error())
-
-	vals, err = ReadAbsolutePaths(context.Background(), db, vs, "invalid.monkey")
-	assert.Nil(vals)
-	assert.Equal("input path 'invalid.monkey' does not exist in database", err.Error())
-}
-
 func TestAbsolutePathParseErrors(t *testing.T) {
-	assert := assert.New(t)
-
 	test := func(path, errMsg string) {
 		p, err := NewAbsolutePath(path)
-		assert.Equal(AbsolutePath{}, p)
-		assert.Error(err)
-		assert.Equal(errMsg, err.Error())
+		assert.Equal(t, AbsolutePath{}, p)
+		require.Error(t, err)
+		assert.Equal(t, errMsg, err.Error())
 	}
 
 	test("", "empty path")
-	test(".foo", "invalid dataset name: .foo")
-	test(".foo.bar.baz", "invalid dataset name: .foo.bar.baz")
 	test("#", "invalid hash: ")
 	test("#abc", "invalid hash: abc")
 	invHash := strings.Repeat("z", hash.StringLen)
